=========
Collectds
=========

Introduction
------------

Collectds references Fuel-LMA and is modified to collect OpenStack service running status.


Installation
------------
1. Via pip(recommend)::
    
    pip install collectds

2. Via easy_install::
    
    easy_install collectds

2. From source ::
    
    python setup.py install


